from setuptools import setup

setup(
    name="chord",
    version="0.0.2",
    description="Python wrapper around d3-chord",
    url="https://github.com/shahinrostami/chord",
    author="Dr. Shahin Rostami",
    author_email="hello@shahinrostami.com",
    license="MIT",
    packages=["chord"],
    zip_safe=False,
)
